---
output:
  html_document: default
  pdf_document: default
---
## Replication of "Disfavor or Favor? Assessing the Valence of White Americans' Racial Attitudes"
### Alexander Agadjanian, John Carey, Yusaku Horiuchi, and Timothy Ryan
### *Quarterly Journal of Political Science*, forthcoming

***

#### Description

-  When individuals' racial attitudes are associated with their judgments related to race---for example, when people with more negative attitudes toward Blacks are less likely to vote for a Black political candidate---existing studies routinely interpret it as evidence of prejudice against minorities. But theoretically, such associations can represent favoring minorities, disfavoring them, or a combination of both. We provide a conceptual framework to distinguish patterns of favoring and disfavoring against a standard of racial indifference, and test it with a pre-registered conjoint experiment. In our results, one widely-used measure---the Racial Resentment Scale (RRS)---captures favoring of Blacks substantially more than disfavoring. This finding calls for greater care in characterizing white Americans' racial attitudes and illustrates ways to improve future research designs. We also describe several extensions that integrate the distinction between favoring and disfavoring into the broader study of racial attitudes.

#### Program: 

- R (version 4.0.4)

#### Additional programs required: 

- `tidyverse` (version 1.3.1)
- `lubridate` (version 1.8.0)
- `ggthemes` (version 4.2.4)
- `estimatr` (version 0.30.2)
- `cowplot` (version 1.1.1)
- `fabricatr` (version 0.14.0) 
- `haven` (version 2.4.3)
- `patchwork` (version 1.1.1) 


#### Setting the working directory

- If you use RStudio, click `agadjanian-carey-horiuchi-ryan.Rproj` to launch RStudio and set the working directory automatically. 
- If you do not use RStudio, manually set the working directory, which is the folder that includes `agadjanian-carey-horiuchi-ryan.Rproj`.

#### Process of replication

- Run `master.R`, which installs necessary packages and runs all scripts sequentially. 
- Alternatively, install packages manually. Then, run the scripts sequentially; first, the scripts in `build/scripts`, then, the scripts in `analyze/scripts`.

#### Most recent date of successful replication

December 18, 2021

#### About data

- This project includes three sets of data
  - The main two-wave survey data 
    - `/build/data/ACHR_Wave_1 - choice text (after data collection was paused on November 5).csv`
    - `/build/data/ACHR_Wave_1 - numeric values (after data collection was paused on November 5).csv`
    - `/build/data/ACHR_Wave_2 - choice text.csv`
    - `/build/data/ACHR_Wave_2 - numeric values.csv`
  - The pilot survey data
    - `/build/data/Agadjanian-Carey-Horiuchi-Ryan (Pilot)_May 31, 2019_07.03.csv`
  - The survey data of existing studies
    - `/analyze/data/2014+SSI+constructed+data.dta` (source: https://doi.org/10.7910/DVN/SXJHEJ)
    - `/analyze/data/CCAP 2009 Reinterviews.dta` (source: an email from Michael Tesler)
    - `/analyze/data/desante_experimental_data.dta` (source: https://doi.org/10.7910/DVN/AZTWDW)
    - `/analyze/data/StephensData_JOP.dta` (source: https://doi.org/10.7910/DVN/GLA1FB)

#### Files included in this package

- `README.md`
- `REAME.html` -- generated by `README.md`
- `REAME.pdf` -- generated by `README.md`
- `agadjanian-carey-horiuchi-ryan.Rproj` (for RStudio)
- `master.R` -- a master file that sources all other scripts. 
- `sessionInfo.txt` - information about R, the OS, and attached/loaded packages (saved after running `master.R`)

- build (folder)
  - data (folder)
      - Data used for replication
  - documents (folder)
      - Survey questionnaires (code-books)
      - A screenshot
  - functions (folder)
      - Functions used in the scripts
  - output (folder)
      - All files are generated by the scripts
  - scripts (folder) 
    - R scripts to build data
- analyze (folder)
  - data (folder)
      - Data used for replication
      - `cleaned_data.RData` is generated by running codes in the `build/scripts` folder
      - `pilot_data.rds` is generated by running a code in the `build/scripts` folder
  - figures (folder)
      - All files are generated by the scripts
  - functions (folder)
      - Functions used in the scripts
  - output (folder)
      - All files are generated by the scripts
  - scripts (folder) 
    - R scripts for complete replication


#### Figures and tables in the article

- Figure 1
  - code: `analyze/scripts/step01_typology.R`
  - output: `analyze/figures/three-types-simulated.pdf`

- Figure 2
  - code: n.a. (screenshot)
  - output: `build/documents/sample_task.pdf`

- Figure 3
  - code: `analyze/scripts/step05a_MMby_approaches.R`
  - output: `analyze/figures/MMby_approaches.pdf`

- Figure 4
  - code: `analyze/scripts/step05b_MMby_measures.R`
  - output: `analyze/figures/MMby_racial_groups.pdf`

- Figure 5
  - code: `analyze/scripts/step05c_MMby_ideology.R`
  - output: `analyze/figures/MMby_ideology.pdf`
  
- Figure 6
  - code: `analyze/scripts/step05d_MMby_measures.R`
  - output: `analyze/figures/MMby_measures.pdf`
  
- Table B.1
  - code: n.a.
  - output: made the table manually
  
- Table D.1
  - code: `analyze/scripts/step07_demographics.R`
  - output: `analyze/output/demographics.csv`

- Figure F.1
  - code: `analyze/scripts/analyze/step03_MM.R`
  - output: `analyze/figures/MM_1stSet.pdf`

- Figure F.2
  - code: `analyze/scripts/analyze/step03_MM.R`
  - output: `analyze/figures/MM_twoSets.pdf`

- Figure F.3
  - code: `analyze/scripts/step09_check_order_effects.R`
  - output: `analyze/figures/order_effects.pdf`

- Figure F.4
  - code: `analyze/scripts/step05e_MMby_age_groups.R`
  - output: `analyze/figures/MMby_age_groups.pdf`

- Figure F.5
  - code: `analyze/scripts/step06_correlation_bewteen_measures.R`
  - output: `analyze/figures/racial_attitudes_correlated.pdf`

- Figure F.6
  - code: `analyze/scripts/step05b_MMby_measures.R`
  - output: `analyze/figures/MMby_measures_3cat.pdf`

- Figure G.1
  - code: `analyze/scripts/step11_reanalyze_existing_studies.R`
  - output: `analyze/figures/reanalyses-combined.pdf`

- Figure H.1
  - code: `analyze/scripts/step02_position.R`
  - output: `analyze/figures/occupation_distribution.pdf`
  
- Figure H.2
  - code: `analyze/scripts/step10_MM_pilot.R`
  - output: `analyze/figures/MMs_norace_noparty.pdf`
  
