custom_figure_with_histogram <- function(data, results, x_var, x_label, x_breaks, x_breaks_labels = x_breaks){
  
  enquo_xvar <- enquo(x_var)
  
  df_hist <- data %>% 
    mutate(x_var := !!enquo_xvar) %>% 
    count(x_var) %>% 
    mutate(n = n / 20)
  
  b0 <- -250
  b1 <- 1000
  
  d <- results %>% 
    mutate(x_var := !!enquo_xvar) %>% 
    left_join(df_hist, by = "x_var") %>% 
    mutate(fitted = b0 + fit.fit * b1, 
           upper  = b0 + fit.upr * b1, 
           lower  = b0 + fit.lwr * b1)
  
  ggplot(d, aes(x = x_var)) + 
    geom_col(aes(y = n), 
             color = "white", 
             fill = "lightgray") +
    geom_hline(yintercept = b0 + 0.5 * b1, 
               color = "lightgray", 
               linetype = "dashed") +
    geom_pointrange(aes(y = fitted,
                        ymin = lower,
                        ymax = upper,
                        color = sig)) +
    guides(color = "none") +
    scale_color_manual(values = c("black", "red")) +
    scale_y_continuous(breaks = c(b0 + 0.25 * b1, 
                                  b0 + 0.50 * b1,
                                  b0 + 0.75 * b1), 
                       labels = c("0.25", "0.50", "0.75")) +
    scale_x_continuous(breaks = x_breaks, 
                       labels = x_breaks_labels) +
    coord_cartesian(ylim = c(b0 + 0.25 * b1, 
                             b0 + 0.75 * b1)) +
    labs(y = "Marginal mean", 
         x = x_label) +
    theme_few() 
  
}