# Note: The default for group_var is "", which add a space when facetting figures

test_hypothesis <- function(dataframe, race_var, xlabel, group_var = ""){
  
  nest <- nest_legacy
  unnest <- unnest_legacy
  
  racevar <- enquo(race_var)
  groupvar <- enquo(group_var)
  
  out <- dataframe %>% 
    mutate(race = !!racevar, 
           subgroup = !!groupvar) %>% 
    group_by(subgroup, `Race/ethnicity`) %>% 
    nest() %>% 
    mutate(test = map(data, ~ lm_robust(response_dum ~ 0 + factor(race), data = ., clusters = id)),
           tidied = map(test, tidy)) %>% 
    unnest(tidied, .drop = TRUE) %>% 
    ungroup() %>% 
    mutate(term = str_replace_all(term, "factor\\(race\\)", "") %>% as.numeric(),
           sig = 0,
           sig = ifelse(conf.low > 0.5 & conf.high > 0.5, 1, sig),
           sig = ifelse(conf.low < 0.5 & conf.high < 0.5, 1, sig),
           # sig = 0 if there is only one observation
           sig = ifelse(df == 1, 0, sig))
  
  xmin <- min(out$term)
  xmax <- max(out$term)
  
  ggplot(out) +
    geom_hline(yintercept = 0.5,
               color = "gray",
               linetype = "dashed") +
    geom_smooth(aes(x = term,
                    y = estimate),
                method = 'loess',
                se = FALSE,
                color = "lightgray") +
    geom_pointrange(aes(x = term,
                        y = estimate,
                        ymin = conf.low,
                        ymax = conf.high, 
                        color = factor(sig)),
                    na.rm = TRUE) +
    scale_color_manual(values = c("black", "red")) +
    scale_x_continuous(breaks = c(xmin, xmax)) +
    coord_cartesian(ylim = c(0, 1)) +
    guides(color = "none") +
    theme_few() +
    labs(x = xlabel,
         y = "Marginal mean") +
    facet_grid(subgroup ~ `Race/ethnicity`)
  
}
