# Note: The default for group_var is "", which add a space when facetting figures
test_hypothesis_3cat  <- function(dataframe, race_var, xlabel, group_var = "", gtitle = NULL){
  
  nest <- nest_legacy
  unnest <- unnest_legacy
  
  racevar <- enquo(race_var)
  groupvar <- enquo(group_var)
  
  if (rlang::as_label(racevar) != "collective_guilt"){
    out <- dataframe %>% 
      mutate(race3cat = split_quantile(!!racevar, type = 3))
    cat_labels <- out %>% 
      select(id, race3cat, !!racevar) %>% 
      distinct() %>% 
      group_by(race3cat) %>% 
      summarise(race_min = min(!!racevar),
                race_max = max(!!racevar), 
                race_n = n()) %>% 
      ungroup() %>% 
      mutate(label = NA,
             label = ifelse(race3cat == 1, paste0("Low\n[", race_min, ", ", race_max, "]\n(n = ", race_n, ")"), label),
             label = ifelse(race3cat == 2, paste0("Medium\n[", race_min, ", ", race_max, "]\n(n = ", race_n, ")"), label),
             label = ifelse(race3cat == 3, paste0("High\n[", race_min, ", ", race_max, "]\n(n = ", race_n, ")"), label)) %>% 
      select(label) %>% 
      pull()
    
  } else {
    out <- dataframe %>% 
      mutate(race3cat = 1,
             race3cat = ifelse(collective_guilt %in% 12:14, 2, race3cat),
             race3cat = ifelse(collective_guilt ==15, 3, race3cat))
    cat_labels <- out %>% 
      select(id, race3cat, !!racevar) %>% 
      distinct() %>% 
      group_by(race3cat) %>% 
      summarise(race_min = min(!!racevar),
                race_max = max(!!racevar), 
                race_n = n()) %>% 
      ungroup() %>% 
      mutate(label = NA,
             label = ifelse(race3cat == 1, paste0("High\n[", race_min, ", ", race_max, "]\n(n = ", race_n, ")"), label),
             label = ifelse(race3cat == 2, paste0("Medium\n[", race_min, ", ", race_max, "]\n(n = ", race_n, ")"), label),
             label = ifelse(race3cat == 3, paste0("Low\n[15]\n(n = ", race_n, ")"), label)) %>% 
      select(label) %>% 
      pull()
    
  }
  
  out2 <- out %>% 
    mutate(subgroup = !!groupvar) %>% 
    group_by(subgroup, `Race/ethnicity`) %>% 
    nest() %>% 
    mutate(test = map(data, ~ lm_robust(response_dum ~ 0 + factor(race3cat), data = ., clusters = id)),
           tidied = map(test, tidy)) %>% 
    unnest(tidied, .drop = TRUE) %>% 
    ungroup() %>% 
    mutate(term = str_replace_all(term, "factor\\(race3cat\\)", "") %>% as.numeric(),
           term = factor(term, labels = cat_labels),
           sig = 0,
           sig = ifelse(conf.low > 0.5 & conf.high > 0.5, 1, sig),
           sig = ifelse(conf.low < 0.5 & conf.high < 0.5, 1, sig),
           # sig = 0 if there is only one observation
           sig = ifelse(df == 1, 0, sig))
  
  ggplot(out2) +
    geom_hline(yintercept = 0.5,
               color = "gray",
               linetype = "dashed") +
    geom_pointrange(aes(x = term,
                        y = estimate,
                        ymin = conf.low,
                        ymax = conf.high, 
                        color = factor(sig))) +
    geom_text(aes(x = term,
                  y = estimate, 
                  label = format(round(estimate, digits = 2)),
                  color = factor(sig)),
              nudge_x = 0.3) +
    scale_color_manual(values = c("black", "red")) +
    coord_cartesian(ylim = c(0.4, 0.6),
                    xlim = c(0.9, 3.1)) +
    guides(color = "none") +
    theme_few() +
    labs(title = gtitle,
         x = xlabel,
         y = "Marginal mean") +
    facet_grid(subgroup ~ `Race/ethnicity`)
  
}
