# Note: The default for group_var is "", which add a space when faceting figures

test_hypothesis_cubic <- function(dataframe, race_var, xlabel, group_var = ""){
  
  nest <- nest_legacy
  unnest <- unnest_legacy
  
  racevar <- enquo(race_var)
  
  if (group_var == "") {
    
    d <- dataframe %>% 
      # order Race/ethnicity --- necessary to merge fitted values later
      arrange(`Race/ethnicity`)
    
    out <- d %>% 
      mutate(race = !!racevar, 
             race2 = race^2,
             race3 = race^3) %>% 
      group_by(`Race/ethnicity`) %>% 
      nest() %>% 
      mutate(test = map(data, ~ predict(lm_robust(response_dum ~ 1 + race + race2 + race3, data = ., 
                                                  clusters = id), 
                                        newdata = ., 
                                        se.fit = TRUE, 
                                        interval = "confidence") %>% as.data.frame()
      )) %>% 
      unnest(test, .drop = TRUE) %>% 
      bind_cols(d %>% select(-`Race/ethnicity`)) %>% 
      select(`Race/ethnicity`, !!racevar, fit.fit, fit.lwr, fit.upr) %>% 
      distinct() %>% 
      mutate(sig = FALSE,
             sig = ifelse(fit.lwr > 0.5 & fit.upr > 0.5, TRUE, sig),
             sig = ifelse(fit.lwr < 0.5 & fit.upr < 0.5, TRUE, sig)) %>% 
      mutate(subgroup = "")
    
  } else {
    
    groupvar <- rlang::sym(group_var)
    
    d <- dataframe %>% 
      # order by groupvar and Race/ethnicity --- necessary to merge fitted values later
      arrange(!!groupvar, `Race/ethnicity`)
    
    out <- d %>% 
      mutate(race = !!racevar, 
             subgroup = !!groupvar,
             race2 = race^2,
             race3 = race^3) %>% 
      group_by(subgroup, `Race/ethnicity`) %>% 
      nest() %>% 
      mutate(test = map(data, ~ predict(lm_robust(response_dum ~ 1 + race + race2 + race3, data = ., 
                                                  clusters = id), 
                                        newdata = ., 
                                        se.fit = TRUE, 
                                        interval = "confidence") %>% as.data.frame()
      )) %>% 
      unnest(test, .drop = TRUE) %>% 
      bind_cols(d %>% select(-`Race/ethnicity`)) %>% 
      select(`Race/ethnicity`, !!racevar, subgroup, fit.fit, fit.lwr, fit.upr) %>% 
      distinct() %>% 
      mutate(sig = FALSE,
             sig = ifelse(fit.lwr > 0.5 & fit.upr > 0.5, TRUE, sig),
             sig = ifelse(fit.lwr < 0.5 & fit.upr < 0.5, TRUE, sig))

  }
  
  xmin <- out %>% select(!!racevar) %>% pull() %>% min(.)
  xmax <- out %>% select(!!racevar) %>% pull() %>% max(.)
  
  ggplot(out) +
    geom_hline(yintercept = 0.5, 
               color = "lightgray", 
               linetype = "dashed") +
    geom_pointrange(aes(x = !!racevar, 
                        y = fit.fit, 
                        ymin = fit.lwr,
                        ymax = fit.upr, 
                        color = sig)) +
    facet_grid(subgroup ~ `Race/ethnicity`) +
    guides(color = "none") +
    scale_color_manual(values = c("black", "red")) +
    scale_y_continuous(breaks = c(0.25, 0.50, 0.75)) +
    scale_x_continuous(breaks = c(xmin, xmax)) +
    coord_cartesian(ylim = c(0.2, 0.8)) +
    labs(y = "Marginal mean", 
         x = xlabel) + 
    theme_few()
  
}
