#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- figure showing the typology
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

suppressPackageStartupMessages(library(tidyverse))
library(ggthemes)

# Simulate data -----------------------------------------------------------

set.seed(20200514)
n <- 100
x <- runif(n) 
e <- rnorm(n, mean = 0, sd = 0.05)

y1 <-  0    - 0.5 * x + e
y2 <-  0.25 - 0.5 * x + e
y3 <-  0.5  - 0.5 * x + e

df <- data.frame(x = x, 
                 y1 = y1,
                 y2 = y2, 
                 y3 = y3) %>% 
  pivot_longer(names_to = "type", cols = 2:4) %>% 
  mutate(type = factor(type, 
                       labels = c("(a) One-sided disfavoring", 
                                  "(b) Two-sided", 
                                  "(c) One-sided favoring")))

# Make figure -------------------------------------------------------------

ggplot(df, 
       aes(x = x, 
           y = value)) +
  facet_wrap(~ type) +
  geom_hline(yintercept = 0, 
             linetype = "dashed", 
             color = "black") +
  geom_point() +
  theme_few() +
  scale_y_continuous(breaks = c(-0.5, 0, 0.5), 
                     labels = c("Disfavor", 
                                "Indifference", 
                                "Favor")) + 
  scale_x_continuous(breaks = c(0.1, 0.5, 0.9), 
                     labels = c("Low", 
                                "Middle", 
                                "High")) +
  labs(x = "\nAttitude", 
       y = "Judgment\n")

# Save figure -------------------------------------------------------------

ggsave("analyze/figures/three-types-simulated.pdf", width = 10, height = 5)
