#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- political relevance of occupation
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(ggthemes)

fig_w <- 10
fig_h <- 8

# Load data ---------------------------------------------------------------

load("analyze/data/cleaned_data.RData")

# Wrangle wave 2 data -----------------------------------------------------

wave1_wrangled <- wave1 %>% 
  select(id, contains("occupation")) %>% 
  gather("occupation", "score", 2:ncol(.)) %>% 
  mutate(score = factor(score, 
                        levels = c("No influence", 
                                   "Very little influence", 
                                   "Some influence", 
                                   "A great deal of influence"),
                        labels = c("No\ninfluence", 
                                   "Very little\ninfluence", 
                                   "Some\ninfluence", 
                                   "A great deal of\n influence")),
         occupation = factor(occupation,
                              labels = c("A city manager\n (the chief executive for a municipality)", 
                                         "A biology professor at a state university",
                                         "A lawyer",
                                         "A musician", 
                                         "An upper-level manager\n at a furniture company", 
                                         "A police detective")))


# Visualize the political relevance of each position ----------------------

# Prepare a data-frame for data-vis.
vis1 <- wave1_wrangled %>% 
  mutate(score_num = as.numeric(score)) %>% 
  group_by(occupation, score) %>% 
  summarise(count = n(), .groups = "drop") %>% 
  ungroup()

# Make figure.
ggplot(vis1,
       aes(x = score,
           y = 100 * count / 1000)) +
  geom_col(fill = "gray") +
  geom_text(aes(label = round(100 * count / 1000, digits = 0)), vjust = -1) +
  scale_y_continuous(limits = c(0, 55), breaks = seq(0, 50, 10)) +
  facet_wrap(~ occupation, ncol = 2) +
  theme_few() +
  labs(y = "Percent", 
       x = "Response")

# Save figure.
ggsave("analyze/figures/occupation_distribution.pdf", width = fig_w, height = fig_h, scale = 1)

# Chi-square test ---------------------------------------------------------

test <- wave1_wrangled %>% 
  filter(as.numeric(occupation) %in% c(1, 2)) %>% # Use city manager and professor only
  mutate(occupation = as.numeric(occupation),
         occupation = ifelse(occupation == 1, "manager", "professor"),
         score = as.numeric(score))  

table(test$occupation, test$score)
chisq.test(test$occupation, test$score)
# --> statistically highly significant
# City manager position is seen as more political than biology professor position.

# Save the result in a text file
sink("analyze/output/occupation_distribution_chisq.txt")
cat("Cross tabulation")
table(test$occupation, test$score) 
cat("=============================\n")
cat("Chiq-square test results")
chisq.test(test$occupation, test$score)
cat("=============================\n")
cat("(486 + 186) / (115 + 213 + 486 + 186)\n")
(486 + 186) / (115 + 213 + 486 + 186)
cat("(221 + 49) / (311 + 419 + 221 + 49)\n")
(221 + 49) / (311 + 419 + 221 + 49)
sink()

# Save data ---------------------------------------------------------------

occupation <- test %>% 
  spread(occupation, score) %>% 
  mutate(score_diff = manager - professor)

saveRDS(occupation, "analyze/output/occupation.RDS")


