#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- main figure (by three different approaches)
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(estimatr) # lm_robust()
library(ggthemes)
suppressPackageStartupMessages(library(cowplot))
library(fabricatr) # split_quantile()

fig_w <- 10
fig_h <- 5
fig_s <- 1

ymin <- 0.25
ymax <- 0.75

b0 <- -250
b1 <- 1000

xlabel <- "Racial resentment scale (4 items)"

source("analyze/functions/test_hypothesis.R")
source("analyze/functions/test_hypothesis_3cat.R")
source("analyze/functions/test_hypothesis_cubic.R")
source("analyze/functions/make_figure.R")
source("analyze/functions/make_figure_with_hist.R")
source("analyze/functions/custom_plot_grid.R")

# Load data ---------------------------------------------------------------

load("analyze/output/cleaned_data_for_MMby.RData")

# Only focus on city managers
df <- df %>% 
  filter(position == "manager")

# Save results ------------------------------------------------------------

g1 <- test_hypothesis(df, racial_resentment_4items, xlabel)
g2 <- test_hypothesis_3cat(df, racial_resentment_4items, xlabel)
g3 <- test_hypothesis_cubic(df, racial_resentment_4items, xlabel)

g1_blacks <- g1$data %>% filter(`Race/ethnicity` == "Black")
g2_blacks <- g2$data %>% filter(`Race/ethnicity` == "Black") 
g3_blacks <- g3$data %>% filter(`Race/ethnicity` == "Black")

# Marginal means by every level of RRS ------------------------------------

fig1 <- make_figure(g1_blacks) +
  coord_cartesian(ylim = c(ymin, ymax)) +
  scale_x_continuous(limits = c(4, 20), breaks = c(4,20)) 

# Marginal means by a cubic regression model ------------------------------

df_hist <- df %>% 
  count(racial_resentment_4items) %>% 
  mutate(n = n / 20)

d <- g3_blacks %>% 
  left_join(df_hist, by = "racial_resentment_4items") %>% 
  mutate(term = racial_resentment_4items,
         fitted = b0 + fit.fit * b1, 
         upper  = b0 + fit.upr * b1, 
         lower  = b0 + fit.lwr * b1)

fig2 <- make_figure_with_hist(d, b0, b1, xlabel = xlabel)

# Marginal means by terciles ----------------------------------------------

fig3 <- make_figure(g2_blacks) +
  geom_text(aes(x = term,
                y = estimate, 
                label = format(round(estimate, digits = 2)),
                color = factor(sig)),
            nudge_x = 0.3) +
  coord_cartesian(ylim = c(ymin, ymax),
                  xlim = c(0.9, 3.1))

# Merge and save figure ---------------------------------------------------

custom_plot_grid(fig1, fig2, fig3)
ggsave("analyze/figures/MMby_approaches.pdf", width = fig_w, height = fig_h, scale = fig_s)
