#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- main figure (by non-black racial groups)
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(estimatr) # lm_robust()
library(ggthemes)

fig_w <- 10
fig_h <- 5
fig_s <- 1

ymin <- 0.25
ymax <- 0.75

b0 <- -250
b1 <- 1000

xlabel <- "Racial resentment scale (4 items)"

source("analyze/functions/test_hypothesis_cubic.R")
source("analyze/functions/make_figure_with_hist.R")

# Load data ---------------------------------------------------------------

load("analyze/output/cleaned_data_for_MMby.RData")

# Only focus on city managers
df <- df %>% 
  filter(position == "manager")

# Main results ------------------------------------------------------------

g3 <- test_hypothesis_cubic(df, racial_resentment_4items, xlabel)

# Marginal means of selecting non-black racial groups ---------------------

temp1 <- g3$data %>%
  filter(`Race/ethnicity` != "Black") %>%
  rename(term = racial_resentment_4items,
         estimate = fit.fit,
         conf.low = fit.lwr,
         conf.high = fit.upr)

temp2 <- df %>% 
  count(racial_resentment_4items) %>% 
  mutate(n = n / 20) %>% 
  set_names(c("term", "n"))

df_hist <- bind_rows(
  temp2 %>% mutate(`Race/ethnicity` = "Asian"),
  temp2 %>% mutate(`Race/ethnicity` = "Hispanic"),
  temp2 %>% mutate(`Race/ethnicity` = "White")
)

d <- temp1 %>% 
  left_join(df_hist, by = c("Race/ethnicity", "term")) %>% 
  mutate(fitted = b0 + estimate * b1, 
         upper  = b0 + conf.low * b1, 
         lower  = b0 + conf.high * b1)

make_figure_with_hist(d, xlabel = xlabel) +
  facet_wrap(~ `Race/ethnicity`)  
  
# Save figure -------------------------------------------------------------

ggsave("analyze/figures/MMby_racial_groups.pdf", width = fig_w, height = fig_h, scale = fig_s)





