#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- main figure (by age groups)
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(estimatr) # lm_robust()
library(ggthemes)

fig_w <- 10
fig_h <- 5
fig_s <- 1

ymin <- 0.25
ymax <- 0.75

b0 <- -250
b1 <- 1000

xlabel <- "Racial resentment scale (4 items)"

source("analyze/functions/test_hypothesis_cubic.R")
source("analyze/functions/make_figure_with_hist.R")

# Load data ---------------------------------------------------------------

load("analyze/output/cleaned_data_for_MMby.RData")

# Only focus on city managers
df <- df %>% 
  filter(position == "manager")

# Main results ------------------------------------------------------------

df_age <- df %>% 
  mutate(age_group = NA,
         age_group = ifelse(age %in% 18:34, 1, age_group),
         age_group = ifelse(age %in% 35:54, 2, age_group),
         age_group = ifelse(age >= 55, 3, age_group),
         age_group = factor(age_group,
                            labels = c("18-34", 
                                       "35-54",
                                       "55 and over")))

g <- df_age %>% 
  test_hypothesis_cubic(racial_resentment_4items, xlabel, "age_group")
  
# Marginal means by age groups --------------------------------------------

temp <- g$data %>% 
  filter(`Race/ethnicity` == "Black") %>% 
  rename(age_group = subgroup, 
         term = racial_resentment_4items,
         estimate = fit.fit,
         conf.low = fit.lwr,
         conf.high = fit.upr)


df_hist <- df_age %>% 
  group_by(age_group) %>% 
  count(racial_resentment_4items) %>% 
  mutate(n = n / 20) %>% 
  ungroup() %>% 
  set_names(c("age_group", "term", "n"))

d <- temp %>% 
  left_join(df_hist, by = c("age_group", "term")) %>% 
  mutate(fitted = b0 + estimate * b1, 
         upper  = b0 + conf.low * b1, 
         lower  = b0 + conf.high * b1)

make_figure_with_hist(d, xlabel = xlabel) +
  facet_wrap(~ age_group)  

# Save figure -------------------------------------------------------------

ggsave("analyze/figures/MMby_age_groups.pdf", width = fig_w, height = fig_h, scale = fig_s)


