#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- correlation between the measures of racial attitudes
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(ggthemes)
library(fabricatr) # split_quantile()

fig_w <- 10
fig_h <- 8

nest <- nest_legacy
unnest <- unnest_legacy

# Load data ---------------------------------------------------------------

load("analyze/output/cleaned_data_for_MMby.RData")

# Data wrangling for correlation analysis ---------------------------------

df_cor <- racial_attitudes %>% 
  rename(rr4 = racial_resentment_4items,
         rr6 = racial_resentment_6items,
         st = stereotype_diff,
         wid3 = white_identity_3items,
         wid4 = white_identity_4items,
         guilt = collective_guilt) %>%
  select(-id) %>% 
  cor() %>%
  as.data.frame() %>% # turn into data frame
  tibble::rownames_to_column(var = "measure1") %>% # retain row name
  gather(measure2, corr, rr4:guilt) %>% # create columns for each measure
  filter(!duplicated(corr), corr!=1) # drop duplicates and same-measure comparisons

# Reorder measure1
df_cor$measure1 <- factor(df_cor$measure1, levels = c("rr6", "st", "wid3", "wid4", "guilt"))

# Make figure -------------------------------------------------------------

ggplot(data = df_cor,
       aes(x = measure1,
           y = measure2)) +
  geom_tile(aes(fill = corr),
            color = "gray10") +
  geom_text(aes(label = sprintf("%0.2f", round(corr, 2)) )) +
  scale_fill_gradient(low = "white", 
                      high = "gray", 
                      name = "Pairwise correlation") +
  annotate(x = 0.5, y = 4.4, geom = "text", label = "rr4 = Racial Resentment (4 items)", hjust = 0) +
  annotate(x = 0.5, y = 4.6, geom = "text", label = "rr6 = Racial Resentment (6 items)", hjust = 0) +
  annotate(x = 0.5, y = 4.8, geom = "text", label = "st = Racial Stereotype", hjust = 0) +
  annotate(x = 0.5, y = 5.0, geom = "text", label = "wid3 = White Identity (3 items)", hjust = 0) +
  annotate(x = 0.5, y = 5.2, geom = "text", label = "wid4 = White Identity (4 items)", hjust = 0) +
  annotate(x = 0.5, y = 5.4, geom = "text", label = "guilt = Collective Guilt", hjust = 0) +
  theme_few() +
  theme(legend.position = "top") +
  labs(x = NULL, y = NULL)

# Save figure -------------------------------------------------------------

ggsave("analyze/figures/racial_attitudes_correlated.pdf", width = fig_h, height = fig_h, scale = 0.8)
