#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- sample demographics.
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)

# Load data ---------------------------------------------------------------

load("analyze/data/cleaned_data.RData")

# Wrangle data ------------------------------------------------------------

df <- wave1 %>%
  mutate(educ = case_when(education %in% c("High school diploma", "Less than high school") ~ "High school or less",
                          TRUE ~ education),
         agecat = case_when(age>=18 & age<=24 ~ "18-24",
                            age>=25 & age<=34 ~ "25-34",
                            age>=35 & age<=44 ~ "35-44",
                            age>=45 & age<=54 ~ "45-54",
                            age>=55 & age<=89 ~ "55+"),
         reg = case_when(str_detect(region, "<strong>Midwest") ~ "Midwest",
                         str_detect(region, "<strong>Northeast") ~ "Northeast",
                         str_detect(region, "<strong>South") ~ "South",
                         str_detect(region, "<strong>West") ~ "West"),
         pid = case_when(party=="Democrat" & party_strength=="Not very strong" ~ "Democrat",
                         party=="Democrat" & party_strength=="Strong" ~ "Democrat",
                         party=="Republican" & party_strength=="Not very strong" ~ "Republican",
                         party=="Republican" & party_strength=="Strong" ~ "Republican",
                         party=="Independent" & party_leaning=="Closer to the Democratic Party" ~ "Democrat",
                         party=="Other / Don't know" & party_leaning=="Closer to the Democratic Party" ~ "Democrat",
                         party=="Independent" & party_leaning=="Closer to the Republican Party" ~ "Republican",
                         party=="Other / Don't know" & party_leaning=="Closer to the Republican Party" ~ "Republican",
                         party=="Independent" & party_leaning=="I do not lean toward either of the two parties" ~ "Pure Independent",
                         party=="Other / Don't know" & party_leaning=="I do not lean toward either of the two parties" ~ "Pure Independent"),
         ideo = case_when(str_detect(ideology, "[Cc]onservative") ~ "Conservative",
                          str_detect(ideology, "[Ll]iberal") ~ "Liberal",
                          TRUE ~ "Moderate/Haven't thought much about this")) %>% 
  select(id, educ, gender, agecat, reg, pid, ideo) %>% 
  pivot_longer(cols = 2:ncol(.), names_to = "variable", values_to = "subgroup") %>% 
  group_by(variable, subgroup) %>% 
  summarise(n = n(), .groups = "drop") %>% 
  group_by(variable) %>% 
  mutate(share = round(100 * n / sum(n), digits = 0)) %>% 
  select(-n)

# Save table --------------------------------------------------------------

write_csv(df, "analyze/output/demographics.csv")



