#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- Goodness of fit
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(estimatr) # lm_robust()

source("analyze/functions/test_hypothesis_cubic.R")

# Load data ---------------------------------------------------------------

load("analyze/output/cleaned_data_for_MMby.RData")

df <- df %>% 
  mutate(ideology2 = NA,
         ideology2 = ifelse(ideology %in% c("Conservative", "Slightly conservative", "Extremely conservative"), "conservative", ideology2),
         ideology2 = ifelse(ideology %in% c("Liberal", "Slightly liberal", "Extremely liberal"), "liberal", ideology2))
  
# Weighted percentage favoring --------------------------------------------

calculate_wpf <- function(data, 
                          attitude_variable,
                          race_ethnicity = "Black", 
                          position_name = "manager"){

  var_quo <- enquo(attitude_variable)
  
  d <- data %>% 
    filter(`Race/ethnicity` == race_ethnicity, position == position_name) %>% 
    mutate(attitude := !!var_quo)

  out <- lm_robust(response_dum ~ attitude + I(attitude^2) + I(attitude^3), clusters = id, data = d)
  
  test <- bind_cols(d, 
                    data.frame(fitted = out$fitted.values)) %>% 
    select(id, fitted, attitude) %>% 
    distinct() %>% 
    group_by(attitude) %>% 
    mutate(n = n()) %>% 
    ungroup() %>% 
    select(-id) %>% 
    distinct() %>% 
    mutate(favoring = ifelse(fitted > 0.5, 1, 0),
           deviation = abs(fitted - 0.5), 
           weight = deviation / sum(deviation), 
           n_weighted = n * weight) %>% 
    arrange(attitude)
  
  # print(test %>% as.data.frame())
  
  counts <- test %>% 
    group_by(favoring) %>% 
    summarise(n = sum(n)) %>% 
    ungroup() %>% 
    mutate(pct = n / sum(n))
  
  n_favoring    <- counts[counts$favoring == 1, "n"] %>% pull()
  n_disfavoring <- counts[counts$favoring == 0, "n"] %>% pull()
  
  wpf <- test %>% 
    group_by(favoring) %>% 
    summarize(x = sum(n_weighted)) %>% 
    ungroup() %>% 
    mutate(pct = x / sum(x)) %>% 
    filter(favoring == 1) %>% 
    select(pct) %>% pull()
  
  data.frame("attitude" = rlang::quo_text(var_quo), 
             "race_ethnicity" = race_ethnicity,
             "position" = position_name,
             "n_fav" = n_favoring,
             "n_disfav" = n_disfavoring,
             "wpf" = wpf) %>% 
    return()

}

out <- bind_rows(
  calculate_wpf(df, racial_resentment_4items),
  calculate_wpf(df, racial_resentment_4items, race_ethnicity = "Asian"),
  calculate_wpf(df, racial_resentment_4items, race_ethnicity = "Hispanic"),
  calculate_wpf(df, racial_resentment_4items, position_name = "professor")
  
)

write_csv(out, "analyze/output/weighted_pct_favoring.csv")

