#' Agadjanian-Carey-Horiuchi-Ryan
#' Analyze -- check order effects
#'
#' last update: December 12, 2021

# Initial settings --------------------------------------------------------

library(tidyverse)
library(estimatr) # lm_robust()
library(ggthemes)

fig_w <- 10
fig_h <- 5
fig_s <- 1

xlabel <- "Racial resentment scale (4 items)"

source("analyze/functions/test_hypothesis_cubic.R")

# Load data ---------------------------------------------------------------

load("analyze/output/cleaned_data_for_MMby.RData")

# Test the order effects --------------------------------------------------

out <- df %>% 
  # Only focus on city managers
  filter(position == "manager") %>% 
  # Only focus on Black
  filter(`Race/ethnicity` == "Black") %>% 
  # Regression analysis
  group_by(first) %>% 
  nest() %>% 
  mutate(fitted = map(data, ~lm_robust(response_dum ~ factor(task), data = ., cluster = id)),
         tidied = map(fitted, tidy)) %>% 
  unnest(tidied) %>% 
  ungroup() %>% 
  filter(term != "(Intercept)") %>% 
  mutate(term = str_replace_all(term, "factor\\(task\\)", "") %>% as.numeric())

df %>% 
  # Only focus on city managers
  filter(position == "manager") %>% 
  # Only focus on Black
  filter(`Race/ethnicity` == "Black") %>% 
  # Regression analysis
  group_by(first, task) %>% 
  summarise(n = n(), .groups = "drop") %>% 
  ungroup()


ggplot(out) +
  geom_hline(yintercept = 0,
             linetype = "dashed", 
             color = "gray") +
  geom_pointrange(aes(x = term,
                      y = estimate, 
                      ymin = conf.low,
                      ymax = conf.high)) +
  facet_wrap(~ factor(first, 
                      labels = c("City manager first", "Biology professor first")))+
  theme_few() +
  labs(x = "Conjoint task number", 
       y = "Difference in the marginal mean from the first task")
  
ggsave("analyze/figures/order_effects.pdf", width = fig_w, height = fig_h, scale = fig_s)  



