# Function to re-shape Conjoint data
reshape_conjoint <- function(df) {
  
  n_res <- nrow(df)
  type <- "B" # For this particular research, no need to assign "B" to type. 
  # But leave this line because this function can be used for 
  # other research in which we may need to assign the letter (e.g., B)
  # as an input parameter
  
  temp1 <- df %>%
    select(id, position, contains(paste0(type, "."))) %>% 
    gather("code", "name", 3:ncol(.)) %>% 
    filter(str_detect(code, paste0(type, ".\\d+.\\d+$"))) %>% 
    separate(code, into = c("x", "task", "attribute"), sep = "\\.") %>%
    select(-x) %>%
    rename(attribute_name = name)
  
  temp2 <- df %>%
    select(id, position, contains(paste0(type, "."))) %>% 
    gather("code", "name", 3:ncol(.)) %>% 
    filter(str_detect(code, paste0(type, ".\\d+.\\d+.\\d+"))) %>%
    separate(code, into = c("x", "task", "profile", "attribute"), sep = "\\.") %>%
    select(-x) %>%
    rename(level_name = name)
  
  # Make a data-frame with attribute-levels.
  attribute_levels <- left_join(temp1, temp2,
                                by = c("id", "position", "task", "attribute")) %>%
    select(-attribute) %>% 
    mutate_at(c("task", "profile"), .funs = as.numeric) %>% 
    rename(attribute = attribute_name,
           level = level_name) %>% 
    group_by(id, position, task, profile) %>% 
    spread(key = attribute, value = level) %>% 
    ungroup()
  
  # Make a data-frame with responses.
  responses <- df %>%
    select(one_of("id", "position", paste0("Q", 1:10))) %>% 
    gather("task", "response", 3:ncol(.)) %>% 
    arrange(id, position, task) %>% 
    mutate(task = str_replace_all(task, "Q", "") %>% as.integer())
  
  # Merge data and return.
  attribute_levels %>%
    left_join(responses, by = c("id", "position", "task")) %>% 
    return()
  
}