#' Agadjanian-Carey-Horiuchi-Ryan
#' Build -- Read and wrangle the pilot data
#' 
#' last update: December 12, 2021

# Initial setting ---------------------------------------------------------

library(tidyverse)

source("build/functions/read_Survey.R")

# Functions ---------------------------------------------------------------

# Function to reshape the data file ("wide" to "long")
reshape_conjoint <- function(df, type, outcome) {
  
  temp1 <- df %>%
    select(id, contains(paste0(type, "."))) %>% 
    gather("code", "name", 2:ncol(.)) %>% 
    filter(str_detect(code, paste0(type, ".\\d+.\\d+$"))) %>% 
    separate(code, into = c("x", "task", "attribute"), sep = "\\.") %>%
    select(-x) %>%
    rename(attribute_name = name)
  
  temp2 <- df %>%
    select(id, contains(paste0(type, "."))) %>% 
    gather("code", "name", 2:ncol(.)) %>% 
    filter(str_detect(code, paste0(type, ".\\d+.\\d+.\\d+"))) %>%
    separate(code, into = c("x", "task", "profile", "attribute"), sep = "\\.") %>%
    select(-x) %>%
    rename(level_name = name)
  
  attribute_levels <- left_join(temp1, temp2,
                                by = c("id", "task", "attribute")) %>%
    select(-attribute) %>% 
    mutate_at(c("task", "profile"), .funs = as.numeric) %>% 
    rename(attribute = attribute_name,
           level = level_name)
  
  # Drop respondents who saw "blank" conjiont tables
  
  attribute_levels_2 <- attribute_levels %>% 
    mutate(blank = ifelse(is.na(attribute) | is.na(level), 1, 0)) %>% 
    group_by(id) %>% 
    mutate(blank_sum = sum(blank)) %>% 
    ungroup()
  
  attribute_levels_2 %>% count(blank_sum)
  
  attribute_levels_2 <- attribute_levels_2 %>% 
    filter(blank_sum == 0) %>% 
    select(-contains("blank")) %>% 
    # spead() after deleting NA
    spread(attribute, level, convert = TRUE) 
  
  responses <- df %>%
    select(id, contains(paste0(outcome, "."))) %>%
    gather("task", "response", 2:ncol(.)) %>% 
    mutate(task = str_replace_all(task, paste0(outcome, "."), "") %>% as.numeric(),
           task = task / 2)
  
  out <- attribute_levels %>%
    left_join(responses, by = c("id", "task")) %>% 
    mutate(type = type) %>% 
    filter(!is.na(response)) %>% 
    # make an outcome/dichotomous variable
    mutate(response = str_replace_all(response, "Candidate ", "") %>% as.numeric(),
           response = ifelse(response == profile, 1, 0)) 
  
  return(out)  
  
}

# Read data ---------------------------------------------------------------

file <- "build/data/Agadjanian-Carey-Horiuchi-Ryan (Pilot)_May 31, 2019_07.03.csv"

df <- read_Survey(file, n_skip = 3) %>% 
  rename(id = ResponseId) %>% 
  mutate_all(~replace(., . == "", NA))

# Reshape data ------------------------------------------------------------

df2 <- bind_rows(
  reshape_conjoint(df, "A", "Q3"),
  reshape_conjoint(df, "B", "Q4"),
  reshape_conjoint(df, "C", "Q5"),
  reshape_conjoint(df, "D", "Q6")
) %>% 
  left_join(df %>% select(id, position, description), by = "id")

# delete respondents who saw blank conjoint tables
df3 <- df2 %>% 
  filter(!(is.na(attribute) | is.na(level)))

# Add respondent-level variables ------------------------------------------

respondents <- df %>% 
  select(-contains("A."),
         -contains("B."),
         -contains("C."),
         -contains("D."),
         -contains("Q3"),
         -contains("Q4"),
         -contains("Q5"),
         -contains("Q6"),
         -contains("Recipient"),
         -ExternalReference)

df4 <- left_join(df3, respondents, by = c("id", "position", "description"))

# Save data ---------------------------------------------------------------

saveRDS(df4, "analyze/data/pilot_data.rds")

